package com.cim.idm.service;

import com.cim.idm.model.dto.DeliveryDto;
import com.cim.idm.model.po.MaterialReceiveDelivery;
import com.cim.idm.model.po.MaterialReceiveRequest;
import com.cim.idm.model.dto.PageDto;
import com.cim.idm.model.vo.DeliveryReceiveDetailVo;
import com.cim.idm.model.vo.ReceiveDetailVo;
import com.github.pagehelper.PageInfo;

import java.util.List;

public interface IDeliveryService {
    /**
     * 新增到货单
     * @param dto 请求
     * @return 到货单
     */
    String createDelivery(DeliveryDto dto);

    /**
     * 获取采购订单
     * @param dto 请求
     * @return 采购订单
     */
    PageInfo<MaterialReceiveRequest> getPurchase(PageDto dto);

    /**
     * 获取采购单明细及批次
     * @param siteName 组织
     * @param nameList 名称
     * @param deliveryName 到库单号
     * @return 采购订单
     */
    ReceiveDetailVo getStoreDetail(String siteName, List<String> nameList, String deliveryName);

    /**
     * 根据 key 获取值
     * @param siteName 组织
     * @param receiveRequestName 单据名称
     * @return 类型
     */
    MaterialReceiveRequest getByKey(String siteName, String receiveRequestName);

    /**
     * 根据到库单获取采购单名称
     * @param receiveRequestName 到库单
     * @return 采购单名称列表
     */
    List<MaterialReceiveRequest> getReceiveByDelivery(String siteName, String receiveRequestName);

    /**
     * 获取到库单关系
     */
    List<MaterialReceiveDelivery> getRelation(String deliveryName);

    /**
     * 根据到库单获取采购单名称
     * @param nameList 到库单
     * @return 采购单名称列表
     */
    List<DeliveryReceiveDetailVo> getReceiveDetail(List<String> nameList);
}
