package com.cim.idm.service.Impl;

import com.alibaba.fastjson.JSON;
import com.cim.idm.constants.ReceiveTypeEnums;
import com.cim.idm.dao.DeliveryDao;
import com.cim.idm.model.dto.PageDto;
import com.cim.idm.model.dto.PurchaseDto;
import com.cim.idm.model.dto.DeliveryDto;
import com.cim.idm.model.dto.DeliveryRelationDto;
import com.cim.idm.model.po.MaterialReceiveDelivery;
import com.cim.idm.model.po.MaterialReceiveRequest;
import com.cim.idm.model.vo.DeliveryReceiveDetailVo;
import com.cim.idm.model.vo.ReceiveDetailVo;
import com.cim.idm.service.IDeliveryService;
import com.github.pagehelper.PageInfo;
import com.github.pagehelper.page.PageMethod;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;

@Service
public class DeliveryServiceImpl implements IDeliveryService {

    @Resource
    private DeliveryDao deliveryDao;

    @Override
    @Transactional
    public String createDelivery(DeliveryDto dto) {
        // 添加到库单
        if (deliveryDao.createDelivery(dto.getSiteName(),
                dto.getReceiveRequestName(), ReceiveTypeEnums.DK.getCode()) <= 0) {
            return "添加到库单失败";
        }
        // 添加到库单关系
        List<DeliveryRelationDto> res = new ArrayList<>();
        for (DeliveryRelationDto item : dto.getReceiveList()) {
            // 数量大于 0
            if (Objects.nonNull(item.getDeliveryNum()) && item.getDeliveryNum() > 0) {
                // 到库单号
                item.setDeliveryName(dto.getReceiveRequestName());
                res.add(item);
            }
        }
        if (deliveryDao.createRelation(res) <= 0) {
            return "添加到库单关系失败";
        }
        return "更新成功";
    }

    @Override
    public PageInfo<MaterialReceiveRequest> getPurchase(PageDto dto) {
        PageMethod.startPage(dto.getPageNum(), dto.getPageSize());
        PurchaseDto purchaseDto = JSON.toJavaObject(dto.getParams(), PurchaseDto.class);
        return new PageInfo<>(deliveryDao.getPurchase(purchaseDto, ReceiveTypeEnums.getPurchase()));
    }

    @Override
    public ReceiveDetailVo getStoreDetail(String siteName, List<String> nameList, String deliveryName) {
        ReceiveDetailVo receiveDetailVo = new ReceiveDetailVo();
        // 采购单明细
        List<Map<String, Object>> storeDetail = deliveryDao.getStoreDetail(siteName, nameList, deliveryName);
        receiveDetailVo.setStoreDetail(storeDetail);
        // 批次
        List<Map<String, Object>> storeCharge = deliveryDao.getStoreCharge(siteName, nameList);
        receiveDetailVo.setStoreCharge(storeCharge);
        return receiveDetailVo;
    }

    @Override
    public MaterialReceiveRequest getByKey(String siteName, String receiveRequestName) {
        return deliveryDao.getByKey(siteName, receiveRequestName);
    }

    @Override
    public List<MaterialReceiveRequest> getReceiveByDelivery(String siteName, String receiveRequestName) {
        return deliveryDao.getReceiveByDelivery(siteName, receiveRequestName);
    }

    @Override
    public List<MaterialReceiveDelivery> getRelation(String deliveryName) {
        return deliveryDao.getRelation(deliveryName);
    }

    @Override
    public List<DeliveryReceiveDetailVo> getReceiveDetail(List<String> nameList) {
        return deliveryDao.getReceiveDetail(nameList);
    }
}
